"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Slider = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const classNames_1 = require("../../utils/classNames");
const Slider = ({ className, min = 0, max = 100, label, onChange, disabled = false, defaultValue = min, loading = false, }) => {
    const [selectedValue, setSelectedValue] = (0, react_1.useState)(defaultValue);
    const updateSliderBackground = (0, react_1.useCallback)(() => {
        const elem = document.querySelector('.sliderInner');
        elem.style.backgroundSize =
            ((selectedValue - min) * 100) / (max - min) + '% 100%';
    }, [max, min, selectedValue]);
    (0, react_1.useEffect)(() => {
        if (defaultValue < min) {
            setSelectedValue(min);
        }
        updateSliderBackground();
    }, [selectedValue, loading, defaultValue, min, updateSliderBackground]);
    const handleOnBlur = () => {
        //prevents output of value outside of bounds
        let onChangeValue = selectedValue;
        if (!selectedValue) {
            setSelectedValue(min);
            onChangeValue = min;
        }
        if (selectedValue < min) {
            setSelectedValue(min);
            onChangeValue = min;
        }
        if (selectedValue > max) {
            setSelectedValue(max);
            onChangeValue = max;
        }
        onChange(onChangeValue);
    };
    const handleInput = (e) => {
        setSelectedValue(parseInt(e.target.value));
        onChange(selectedValue);
    };
    return !loading ? ((0, jsx_runtime_1.jsxs)("div", { className: 'sliderOuter', children: [(0, jsx_runtime_1.jsx)("label", { className: (0, classNames_1.classNames)(disabled && 'disabled'), children: label }), (0, jsx_runtime_1.jsxs)("div", { className: "wrapper", children: [(0, jsx_runtime_1.jsx)("p", { className: (0, classNames_1.classNames)(disabled && 'disabled', 'value'), children: min }), (0, jsx_runtime_1.jsx)("input", { className: 'sliderInner', type: "range", onChange: handleInput, disabled: disabled, min: min, max: max, value: selectedValue, tabIndex: 1 }), (0, jsx_runtime_1.jsx)("p", { className: (0, classNames_1.classNames)(disabled && 'disabled', 'value'), children: max }), (0, jsx_runtime_1.jsx)("input", { className: 'value current', onChange: (e) => {
                            const { valueAsNumber } = e.target;
                            setSelectedValue(valueAsNumber);
                        }, type: "number", min: min, max: max, onBlur: handleOnBlur, disabled: disabled, value: selectedValue })] })] })) : ((0, jsx_runtime_1.jsx)(Skeleton, {}));
};
exports.Slider = Slider;
const Skeleton = () => {
    return ((0, jsx_runtime_1.jsxs)("div", { className: "sliderOuter", children: [(0, jsx_runtime_1.jsx)("div", { className: "skeletonValue wider" }), (0, jsx_runtime_1.jsxs)("div", { className: "wrapper", children: [(0, jsx_runtime_1.jsx)("div", { className: "skeletonValue" }), (0, jsx_runtime_1.jsx)("input", { className: "sliderInner", type: "range", disabled: true }), (0, jsx_runtime_1.jsx)("div", { className: "skeletonValue" }), (0, jsx_runtime_1.jsx)("div", { className: "skeletonInput", children: (0, jsx_runtime_1.jsx)("div", { className: "skeletonCurrent" }) })] })] }));
};
//# sourceMappingURL=Slider.js.map